aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/configuration.php
diff options
context:
space:
mode:
Diffstat (limited to 'engine/lib/configuration.php')
-rw-r--r--engine/lib/configuration.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/lib/configuration.php b/engine/lib/configuration.php
index 4679a70d8..cbc083bd0 100644
--- a/engine/lib/configuration.php
+++ b/engine/lib/configuration.php
@@ -62,12 +62,12 @@ function elgg_get_data_path() {
}
/**
* Get the root directory for this installation
*
* @return string
* @since 1.8.0
*/
-function elgg_get_root_dir() {
+function elgg_get_root_path() {
global $CONFIG;
return $CONFIG->path;
}
@@ -62,12 +62,12 @@ function elgg_get_data_path() {
}
/**
- * Get the root directory for this installation
+ * Get the root directory path for this installation
*
* @return string